package net.seelisoft.anruflaut;

import android.content.SharedPreferences;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class AnrufProtokoll {

    private final SharedPreferences sharedPrefs;

    public AnrufProtokoll(SharedPreferences sharedPrefs) {
        this.sharedPrefs = sharedPrefs;
    }

    public boolean enthältNr(String nr) {
        try {
            Map<String, String> gültige = leseGültigeEinträge();

            return gültige.containsValue(nr);
        } catch (Throwable t) {
            Logger.log("AnrufProtokoll", "Fehlerhafter Eintrag!");
            return false;
        }
    }

    public void nrHinzufügen(String nr) {
        String ts = LocalDateTime.now().format(DateTimeFormatter.ISO_DATE_TIME);
        Map<String, String> gültige = new HashMap<>();

        try {
            gültige = leseGültigeEinträge();
        } catch (Throwable t) {
            Logger.log("AnrufProtokoll", "Fehlerhafter Eintrag!");
        }

        gültige.put(ts, nr);

        StringBuilder sb = new StringBuilder();
        for (Map.Entry<String, String> e : gültige.entrySet()) {
            sb.append(e.getKey());
            sb.append(",");
            sb.append(e.getValue());
            sb.append(";");
        }

        SharedPreferences.Editor editor = sharedPrefs.edit();
        editor.putString(Constants.SharedPref_Anrufprotokoll, sb.toString());
        editor.apply();
    }

    private Map<String, String> leseGültigeEinträge() {
        Map<String, String> gültige = new HashMap<>();

        String zeile = this.sharedPrefs.getString(Constants.SharedPref_Anrufprotokoll, "");

        if (zeile.equals("")) {
            return gültige;
        }

        LocalDateTime vorXmin = LocalDateTime.now().minusMinutes(Constants.AnrufVerzögerungInMinuten);

        List<String> einträge = Utils.splitSemikolon(zeile);
        for (String eintrag : einträge) {
            if (!eintrag.equals("")) {
                String[] teile = Utils.splitKomaArray(eintrag);
                LocalDateTime ts = LocalDateTime.parse(teile[0], DateTimeFormatter.ISO_DATE_TIME);

                if (ts.isAfter(vorXmin)) {
                    gültige.put(teile[0], teile[1]);
                }
            }
        }

        return gültige;
    }
}
